# SPDX-License-Identifier: MIT
# Copyright (C) 2021 Max Bachmann

from rapidfuzz.cpp_string_metric import (
    levenshtein,
    normalized_levenshtein,
    levenshtein_editops,
    hamming,
    normalized_hamming,
    jaro_similarity,
    jaro_winkler_similarity
)



from typing import Callable, Hashable, Sequence, Optional, Union, overload, TypeVar

_StringType = Sequence[Hashable]
S1 = TypeVar("S1")
S2 = TypeVar("S2")

def ratio(
    s1: S1, s2: S2, *,
    processor: Optional[Callable[[Union[S1, S2]], _StringType]] = ...,
    score_cutoff: Optional[float] = 0) -> float: ...

def partial_ratio(
    s1: S1, s2: S2, *,
    processor: Optional[Callable[[Union[S1, S2]], _StringType]] = ...,
    score_cutoff: Optional[float] = 0) -> float: ...

def token_sort_ratio(
    s1: S1, s2: S2, *,
    processor: Optional[Callable[[Union[S1, S2]], _StringType]] = ...,
    score_cutoff: Optional[float] = 0) -> float: ...

def token_set_ratio(
    s1: S1, s2: S2, *,
    processor: Optional[Callable[[Union[S1, S2]], _StringType]] = ...,
    score_cutoff: Optional[float] = 0) -> float: ...

def token_ratio(
    s1: S1, s2: S2, *,
    processor: Optional[Callable[[Union[S1, S2]], _StringType]] = ...,
    score_cutoff: Optional[float] = 0) -> float: ...

def partial_token_sort_ratio(
    s1: S1, s2: S2, *,
    processor: Optional[Callable[[Union[S1, S2]], _StringType]] = ...,
    score_cutoff: Optional[float] = 0) -> float: ...

def partial_token_set_ratio(
    s1: S1, s2: S2, *,
    processor: Optional[Callable[[Union[S1, S2]], _StringType]] = ...,
    score_cutoff: Optional[float] = 0) -> float: ...

def partial_token_ratio(
    s1: S1, s2: S2, *,
    processor: Optional[Callable[[Union[S1, S2]], _StringType]] = ...,
    score_cutoff: Optional[float] = 0) -> float: ...

def WRatio(
    s1: S1, s2: S2, *,
    processor: Optional[Callable[[Union[S1, S2]], _StringType]] = ...,
    score_cutoff: Optional[float] = 0) -> float: ...

def QRatio(
    s1: S1, s2: S2, *,
    processor: Optional[Callable[[Union[S1, S2]], _StringType]] = ...,
    score_cutoff: Optional[float] = 0) -> float: ...



# SPDX-License-Identifier: MIT
# Copyright (C) 2021 Max Bachmann

from rapidfuzz.cpp_fuzz import (
    ratio,
    partial_ratio,
    token_sort_ratio,
    partial_token_sort_ratio,
    token_set_ratio,
    partial_token_set_ratio,
    token_ratio,
    partial_token_ratio,
    WRatio,
    QRatio
)
